Documentation
¶
Overview ¶
Package store the package is in diffent folder to reduce the import cycles from the ./context/context.go *
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IStore ¶
type IStore interface {
Get(interface{}) interface{}
GetString(key interface{}) string
GetInt(key interface{}) int
Set(interface{}, interface{}) error
Delete(interface{}) error
Clear() error
VisitAll(func(interface{}, interface{}))
GetAll() map[interface{}]interface{}
ID() string
LastAccessedTime() time.Time
SetLastAccessedTime(time.Time)
Destroy()
}
IStore is the interface which all session stores should implement
Click to show internal directories.
Click to hide internal directories.